#
# spec file for package gnome-nibbles
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-nibbles
Version:        4.2.2
Release:        1.1
Summary:        Worm Game for GNOME
License:        GPL-3.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            https://gitlab.gnome.org/GNOME/gnome-nibbles/-/wikis/home
Source0:        %{name}-%{version}.tar.zst
BuildSystem:    meson
BuildOption:    -Duse_libadwaita=true

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  meson >= 0.50.1
BuildRequires:  vala
BuildRequires:  yelp-tools

%description
Nibbles is a worm game for GNOME. The player controls a 2D worm while
trying to get food. Getting food gives points, but hitting anything
causes a loss of points. When all points are lost, the player loses.

%lang_package

%generate_buildrequires
%meson_buildrequires

%install -a
%fdupes %{buildroot}/%{_datadir}
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.gnome.Nibbles.desktop
%{_datadir}/dbus-1/services/org.gnome.Nibbles.service
%{_datadir}/glib-2.0/schemas/org.gnome.Nibbles.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Nibbles*.*
%{_datadir}/metainfo/org.gnome.Nibbles.appdata.xml
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Apr 17 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.2:
  + Fix issues:
  - glgo/GNOME/gnome-nibbles#74
  - glgo/GNOME/gnome-nibbles#75
* Sun Apr 13 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.1:
  + Fix the problem that the process does not exit cleanly (after a
    timeout) when running as GApplication service.
  + Revert commit
    https://gitlab.gnome.org/GNOME/gnome-nibbles/-/commit/fd432d46e4f8139a2489d4b66ad89f85be7a22e3
    as it causes the volume to vary during the playing of a sound
    file. This revert brings back the gsound build dependency.
* Thu Mar 13 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.0:
  + Fixed various issues.
* Fri Feb 21 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Change spec file to use modern BuildSystem: meson with automatic
  build dependency detection.
- Drop all BuildRequires now autogenerated by meson_buildrequires
  macro.
* Fri Feb 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.rc6:
  + Various bugfixes.
* Tue Feb 11 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.rc5:
  + Removed C++ style comments to improve C compatibility.
  + Ensure the game is over when all the human worms are dead.
  + Changed the developer id to rDNS format.
  + Do not link with libadwaita if the meson link test fails.
  + Build dependency changes; meson >= 1.1, gsound removed.
  + Updated translations.
- Drop pkgconfig(gsound) BuildRequires: No longer needed.
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.rc4:
  + Switch to existing window instead of creating new one on second
    activation.
* Fri Dec 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.2.rc2:
  + Build dependency changes; meson >= 1.1
  + Retired old wiki page; https://wiki.gnome.org/Apps/Nibbles
  + Implemented a new wiki:
    https://gitlab.gnome.org/GNOME/gnome-nibbles/-/wikis/home
  + Updated translations.
- Set URL to the new wiki page.
- Pass -Duse_libadwaita=true to meson: enable Adwaita support.
  Triggers dependency on newer GTK4.
* Thu Sep 12 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.1.0:
  + Silence C compiler warnings
  + Various fixes.
  + Updated translations.
* Wed Aug 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.1.beta:
  + May be linked with libadwaita for a different look.
  + Fixed various issues.
  + Fix worm head tests.
  + Updated translations.
- Add disabled pkgconfig(libadwaita-1) BuildRequires: New optional
  dependency.
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini
* Wed Apr 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.0.4:
  + Fix compile issue with vala >= 0.57.
  + Fix / work around for issue #69 (segfault at game start).
  + Updated translations.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.0.3:
  + Updated translations.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.0.2:
  + Fixes for compatibility with gcc >= 14.0 & clang >= 16
  + Updated translations.
* Fri Nov 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.rc2:
  + Dependency changes:
  - Updated to use gtk4 (>=4.6)
  - libgnome-games-support (>=2.0.0).
  - Dropped gtk3, cogl, clutter, clutter-gtk.
  - Added pangocairo
  - glib target version of 2.78.
  + Feature: added a 3D view.
  + Fix issues:
  - Computer Worms get stuck
  - Keys do not work in a non-Latin keyboard layout
  + Updated translations.
- Drop pkgconfig(clutter-1.0), pkgconfig(clutter-gtk-1.0),
  pkgconfig(gtk+-3.0) and pkgconfig(libgnome-games-support-1)
  BuildRequires following upstream changes.
- Add pkgconfig(gtk4), pkgconfig(libgnome-games-support-2) and
  pkgconfig(pangocairo) BuildRequires following upstream changes.
* Tue May  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.3:
  + Fixes to build with newer valac.
  + Misc merge requests.
  + Updated user help.
  + Updated translations.
- Drop 1b48446068608aff9b5edf1fdbd4b8c0d9f0be94.patch: Fixed
  upstream.
- Add desktop-file-utils BuildRequires: New dependency.
* Thu Feb 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 1b48446068608aff9b5edf1fdbd4b8c0d9f0be94.patch: Fix build
  with vala 0.51.x.
* Mon Nov  2 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Crash fixed.
  + Updated translations.
* Tue Oct  6 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Keyboard shortcuts dialog and multiple shortcuts improvements.
  + Add various command line arguments.
- Changes from version 3.37.0:
  + Rework worms directions code.
  + Many fixes to Control screen.
  + Remove preferences dialog and create new pre-game screen with
    options.
  + Many other fixes and improvements.
  + Updated translations.
* Sat Jul  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Fix button label in documentation.
  + Fix bug related to parsing colors on non-English versions of
    the game.
  + Fix end-of-game screen being covered by another view.
  + Fix bug causing the game to remain paused if restarted while
    being paused.
  + Fix right arrow on controls screen in Turkish locale.
  + Update translations.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + No changes, stable version update only.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.90:
  + Updated help pages.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Jan  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Updated translations.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Update appdata file.
* Fri Sep 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
* Wed Sep  4 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Drop libcanberra in favor of gsound.
  + Port to meson build system.
- Switch to meson.
- Drop libcanberra from BuildRequires, and add gsound.
- Drop intltool from BuildRequires, and add gettext.
- Require vala to build.
- Adjust icons directory in %%files.
* Mon Aug  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated user help.
  + Updated translations.
* Fri Jan  4 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Fix display of level completed label and next level button.
  + Replace app menu with window menu.
  + Updated translations.
* Wed Aug 22 2018 bjorn.lie@gmail.com
- Update to version 3.24.1:
  + Fix missing label and button on level completed screen.
  + Updated translations.
- Drop hicolor-icon-theme and update-desktop-files BuildRequires
  and glib2_gsettings_schema_requires, suse_update_desktop_file
  macros, and post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un), no
  longer needed.
- Use autosetup and make_build macros.
- Add fdupes BuildRequires and corresponding macro, remove dupes.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Updated translations.
* Tue Feb 28 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Updated translations.
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + Updated translations.
* Sat Nov 12 2016 dimstar@opensuse.org
- Update to version 3.23.1:
  + Set default widget on level completed screen.
  + Updated translations.
* Fri Nov 11 2016 dimstar@opensuse.org
- Update to version 3.22.2.2:
  + Updated translations.
- Changes from version 3.22.2.1:
  + Updated translations.
- Changes from version 3.22.2:
  + Updated translations.
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Fix libgnome-games-support target.
  + Updated translations.
- Replace pkgconfig(libgnome-games-support-1.0) BuildRequires with
  pkgconfig(libgnome-games-support-1), following upstreams port.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Set default widgets on new game screens.
  + Work around broken GtkStack transitions on Wayland.
  + Fix incorrect license displayed in preferences dialog.
  + Build with new libgnome-games-support.
  + Updated translations.
- Replace pkgconfig(libgames-support-1.0) BuildRequires with
  pkgconfig(libgnome-games-support-1.0), following upstreams port.
* Sun Jul 17 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Dist the gresource file.
  + Updated translations.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Simplify GResource handling.
  + Updated translations.
- No longer obsolete gnibbles(-lang), it's been gone sine GNOME
  3.7.x, and there is no support for update from such an old
  release anymore. Silences a rpmlint warning.
* Mon May 23 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Updated translations.
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.2.1:
  + Remove extra file added in the previous pre-release commit.
- Changes from version 3.20.2:
  + Updated translations.
* Mon Apr 11 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Internationalization bugs fixed.
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Fix a crash when eating a cherry shortly after an apple or a
    banana.
  + Fix minor style issue.
  + Updated translations.
* Sun Feb 28 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Fix New Game/Pause buttons during countown.
  + Fix sounds played when eating a bonus.
  + Restore user help.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Fix CSS problems.
  + Add proper end game screens for all possible outcomes.
  + Use the new scores import API from libgames-support.
  + Fix problem with buttons breaking the game during the end game
    screens.
  + Fix window size increasing with GTK+ 3.20.
  + Fix bug with worm being briefly uncontrollable at the start of
    a level.
  + Add buttons for selecting the number of AI players.
  + Update project license.
  + Add screen congratulating the player when reaching the last
    level of the game.
  + Updated translations.
- Update license tag to GPL-3.0+, following upstreams changes.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Added preferences dialog.
  + Updated translations.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Make worms spawning on top of other worms ghosts until they
    move to a safe area.
  + Reset level when starting a new game.
- Changes from version 3.19.2:
  + Use gettext.
  + Updated translations.
- Add pkgconfig(gee-0.8) and pkgconfig(libgames-support-1.0)
  BuildRequires: new dependencies.
- Drop pkgconfig(librsvg-2.0) BuildRequires: no longer needed.
* Tue Nov 10 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Sun Oct 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Thu Aug 13 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Fix typos in documentation.
  + Updated translations.
* Wed Jun 24 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata for openSUSE 42.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Provide symbolic app icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Remove the two asserts that crash the most for the "stable"
    release.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91.1:
  + Fix installation of appdata files.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Pause game when viewing preferences or scores.
  + Use gresource, code cleanups.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Don't connect to the windowing system when parsing command line
    options.
  + Don't allow setting the number of human players to zero.
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Disable some asserts for stable branch.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Drop special permission handling, incl pwdutils Requires: this
  was required back when there was a system wide, shared highscore
  list.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Make game delay configurable by debug switch.
  + Updated translations.
* Tue Sep  2 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Make all animations depend on already existing game delay
    constant.
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Fix several causes of invisible death worms, but a few known
    cases remain.
  + The game will now crash whenever an invisible death worm would
    be created.
  + Fix pause action in app menu.
  + Fix resizing the board.
  + Remove seriously buggy random teleporter on level 25.
  + Use header bar on preferences dialog.
  + Don't allow multiple windows.
  + Fix small memory leak.
  + Code cleanups.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Set a minimum size correctly, fixed major resize issue.
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Properly change the state of the pause action.
  + Update URLs.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90.1:
  + Added GtkHeaderBar, bumps depends to GTK+ 3.10.
* Sun Feb 16 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + AppData improvements.
- Replace %%suse_update_desktop_file gnibbles with
  %%suse_update_desktop_file gnome-nibbles.
* Mon Feb  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + GtkApplication Port with new AppMenu.
  + Fix scores system and move to storing in home.
  + End game will show scores dialog.
  + Updated translations.
- Remove calls to handle score files in /var/games.
- Drop gnome-games-scripts BuildRequires: no longer required, as
  we no longer have score files in /var/games.
* Wed Nov 20 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Added AppData file.
  + Minor improvements to translatablity.
  + Code and file cleanups.
  + Updated translations.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 idonmez@suse.com
- Create games user/group on demand (fate#314560)
  + Depend on pwdutils for that to work.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Sun Sep 15 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Added an appdata file.
  + Disable preferences menu when playing.
  + Remove score-dialog that doesn't work.
  + Migrated to Clutter 1.14.4.
  + Help pages updated.
  + Performance improvements and code cleanup.
  + Updated translations.
* Mon Apr  8 2013 dimstar@opensuse.org
- Also obsolete -lang package.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Renamed .desktop file back to gnibbles.desktop.
  + Add HighContrast icon.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
